@@ -1,5 +1,5 @@
 /*
-** $Id: client.js,v 1.60 2009-10-12 09:22:36 jakub Exp $
+** $Id: client.js,v 1.61 2009-10-12 14:35:02 jakub Exp $
 ** Pazpar2's javascript client .
 */
 
@@ -54,7 +54,7 @@ curState.perPage = Number(confShowPerPage);
 curState.page = 0;
 
 curMaxRecs = 100;
-curMaxRecsCount = 1;
+curMaxRecsCount = 0;
 
 
 var resFilters = new mkFilter();
@@ -431,7 +431,7 @@ function historyHandler ( stateJSON )
                     curState.getSingleFilterString() 
                     || resFilters.getFilterString(),
                     curState.page * curState.perPage,
-                    {'maxrecs': curMaxRecs * curMaxRecsCount});
+                    {'startrecs': curMaxRecs * curMaxRecsCount});
                 break;
             case 'show' :
                 if (gotResults) {
@@ -461,7 +461,7 @@ function fetchMore () {
 
 function onFormSubmitEventHandler() 
 {
-    curMaxRecsCount = 1;
+    curMaxRecsCount = 0;
     // load query and clear filter
     loadQueryFromForm();
     curState.clearSingleFilter();
